@@ -11,6 +11,7 @@ import (
 
 	"github.com/skeema/mybase"
 	"github.com/skeema/skeema/internal/fs"
+	"github.com/skeema/skeema/internal/shellout"
 	"github.com/skeema/skeema/internal/tengo"
 	"github.com/skeema/skeema/internal/util"
 	"github.com/skeema/skeema/internal/workspace"
@@ -25,22 +26,12 @@ func TestMain(m *testing.M) {
 }
 
 func TestIntegration(t *testing.T) {
-	images := tengo.SplitEnv("SKEEMA_TEST_IMAGES")
-	if len(images) == 0 {
-		fmt.Println("SKEEMA_TEST_IMAGES env var is not set, so integration tests will be skipped!")
-		fmt.Println("To run integration tests, you may set SKEEMA_TEST_IMAGES to a comma-separated")
-		fmt.Println("list of Docker images. Example:\n# SKEEMA_TEST_IMAGES=\"mysql:5.6,mysql:5.7\" go test")
-	}
-	manager, err := tengo.NewDockerClient(tengo.DockerClientOptions{})
-	if err != nil {
-		t.Errorf("Unable to create sandbox manager: %s", err)
-	}
-	suite := &IntegrationSuite{manager: manager}
+	images := tengo.SkeemaTestImages(t)
+	suite := &IntegrationSuite{}
 	tengo.RunSuite(suite, t, images)
 }
 
 type IntegrationSuite struct {
-	manager         *tengo.DockerClient
 	d               *tengo.DockerizedInstance
 	schema          *tengo.Schema
 	scratchDir      *fs.Dir
@@ -166,7 +157,7 @@ func (s *IntegrationSuite) Setup(backend string) (err error) {
 		RootPassword: "fakepw",
 		CommandArgs:  []string{"--skip-log-bin"}, // override MySQL 8 default of enabling binlog
 	}
-	s.d, err = s.manager.GetOrCreateInstance(opts)
+	s.d, err = tengo.GetOrCreateDockerizedInstance(opts)
 	return err
 }
 
@@ -194,10 +185,7 @@ func (s *IntegrationSuite) BeforeTest(backend string) error {
 
 func (s *IntegrationSuite) setupScratchDir(t *testing.T, subdir string) {
 	t.Helper()
-	shellout := util.ShellOut{
-		Dir:     s.testdata(subdir, "input"),
-		Command: fmt.Sprintf("cp *.sql %s", s.scratchPath()),
-	}
+	shellout := shellout.New("cp *.sql " + s.scratchPath()).WithWorkingDir(s.testdata(subdir, "input"))
 	if err := shellout.Run(); err != nil {
 		t.Fatalf("Unexpected error from shellout: %v", err)
 	}
