@@ -49,6 +49,9 @@ func TestParseDir(t *testing.T) {
 			}
 		}
 	}
+	if dir.retainMapKeyCasing {
+		t.Error("dir retainMapKeyCasing is unexpectedly true")
+	}
 
 	// Confirm that parsing ~ should cause it to be its own repoBase, since we
 	// do not search beyond HOME for .skeema files or .git dirs
@@ -212,40 +215,40 @@ func TestDirGenerator(t *testing.T) {
 func TestDirNamedSchemaStatements(t *testing.T) {
 	// Test against a dir that has no named-schema statements
 	dir := getDir(t, "../../testdata/golden/init/mydb/product")
-	if stmts := dir.NamedSchemaStatements(); len(stmts) > 0 {
-		t.Errorf("Expected dir %s to have no named schema statements; instead found %d", dir, len(stmts))
+	if len(dir.NamedSchemaStatements) > 0 {
+		t.Errorf("Expected dir %s to have no named schema statements; instead found %d", dir, len(dir.NamedSchemaStatements))
 	}
 
 	// named1 has 2 USE statements, and no schema-qualified CREATEs
 	dir = getDir(t, "testdata/named1")
-	if stmts := dir.NamedSchemaStatements(); len(stmts) != 2 {
-		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(stmts))
-	} else if stmts[0].Type != StatementTypeCommand || stmts[1].Type != StatementTypeCommand {
-		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *stmts[0], *stmts[1])
+	if len(dir.NamedSchemaStatements) != 2 {
+		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(dir.NamedSchemaStatements))
+	} else if dir.NamedSchemaStatements[0].Type != tengo.StatementTypeCommand || dir.NamedSchemaStatements[1].Type != tengo.StatementTypeCommand {
+		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *dir.NamedSchemaStatements[0], *dir.NamedSchemaStatements[1])
 	}
 
 	// named2 has 1 schema-qualified CREATE, and 1 USE statement
 	dir = getDir(t, "testdata/named2")
-	if stmts := dir.NamedSchemaStatements(); len(stmts) != 2 {
-		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(stmts))
-	} else if stmts[0].Type != StatementTypeCreate || stmts[1].Type != StatementTypeCommand {
-		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *stmts[0], *stmts[1])
+	if len(dir.NamedSchemaStatements) != 2 {
+		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(dir.NamedSchemaStatements))
+	} else if dir.NamedSchemaStatements[0].Type != tengo.StatementTypeCreate || dir.NamedSchemaStatements[1].Type != tengo.StatementTypeCommand {
+		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *dir.NamedSchemaStatements[0], *dir.NamedSchemaStatements[1])
 	}
 
 	// named3 has 2 schema-qualified CREATEs
 	dir = getDir(t, "testdata/named3")
-	if stmts := dir.NamedSchemaStatements(); len(stmts) != 2 {
-		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(stmts))
-	} else if stmts[0].Type != StatementTypeCreate || stmts[1].Type != StatementTypeCreate {
-		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *stmts[0], *stmts[1])
+	if len(dir.NamedSchemaStatements) != 2 {
+		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(dir.NamedSchemaStatements))
+	} else if dir.NamedSchemaStatements[0].Type != tengo.StatementTypeCreate || dir.NamedSchemaStatements[1].Type != tengo.StatementTypeCreate {
+		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *dir.NamedSchemaStatements[0], *dir.NamedSchemaStatements[1])
 	}
 
 	// named4 has 2 USE statements, and no schema-qualified CREATEs
 	dir = getDir(t, "testdata/named4")
-	if stmts := dir.NamedSchemaStatements(); len(stmts) != 2 {
-		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(stmts))
-	} else if stmts[0].Type != StatementTypeCommand || stmts[1].Type != StatementTypeCommand {
-		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *stmts[0], *stmts[1])
+	if len(dir.NamedSchemaStatements) != 2 {
+		t.Errorf("Expected dir %s to have 2 named schema statements; instead found %d", dir, len(dir.NamedSchemaStatements))
+	} else if dir.NamedSchemaStatements[0].Type != tengo.StatementTypeCommand || dir.NamedSchemaStatements[1].Type != tengo.StatementTypeCommand {
+		t.Errorf("Unexpected statements found in result of NamedSchemaStatements: [0]=%+v, [1]=%+v", *dir.NamedSchemaStatements[0], *dir.NamedSchemaStatements[1])
 	}
 }
 
@@ -278,19 +281,6 @@ func TestParseDirUnterminated(t *testing.T) {
 	}
 }
 
-func TestParseDirInvalidChar(t *testing.T) {
-	// This dir has an invalid operator ("?") which causes the lexer to fail.
-	// It should be handled as a fatal error and the position of the error
-	// should be correct.
-	_, err := ParseDir("testdata/invalidchar", getValidConfig(t))
-	if err == nil {
-		t.Fatal("In dir testdata/invalidchar, expected error from ParseDir(), but instead err is nil")
-	}
-	if msg := err.Error(); !strings.Contains(msg, "testdata/invalidchar/tables.sql:5:15: invalid token '?'") {
-		t.Errorf("Error message did not match expectation; result was %q", msg)
-	}
-}
-
 func TestParseDirUnparsedStatements(t *testing.T) {
 	// This dir contains an INSERT statement among the valid CREATEs. This should
 	// be tracked in dir.UnparsedStatements but isn't a fatal error.
@@ -375,6 +365,95 @@ func TestParseDirIgnorePatterns(t *testing.T) {
 	}
 }
 
+// TestDirParseDirCasingConflict covers situations where object names or file
+// names only differ by casing. Normally we downcase filenames for use as
+// map keys to avoid introducing files which only differ by casing, UNLESS a dir
+// ALREADY has files with such a conflict (which can only happen on a case-
+// sensitive filesystem anyway).
+func TestDirParseDirCasingConflict(t *testing.T) {
+	// Test behavior with empty dir: new conflicts won't be created
+	dirPath := t.TempDir()
+	dir := getDir(t, dirPath)
+	if dir.retainMapKeyCasing {
+		t.Fatal("Expected retainMapKeyCasing to be false, but it was true")
+	}
+	mixedCase := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "Foo"})
+	lowerCase := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "foo"})
+	if expected := filepath.Join(dirPath, "Foo.sql"); mixedCase.FilePath != expected {
+		t.Errorf("Unexpected FilePath: expected %s, found %s", expected, mixedCase.FilePath)
+	} else if lowerCase.FilePath != mixedCase.FilePath {
+		t.Errorf("Unexpected FilePath: expected %s, found %s", mixedCase.FilePath, lowerCase.FilePath)
+	} else if len(dir.SQLFiles) != 1 {
+		t.Errorf("Expected 1 SQL file (both tables using same file), instead found %d", len(dir.SQLFiles))
+	}
+	if another := dir.FileFor(&tengo.Statement{File: filepath.Join(dirPath, "FOO.sql")}); another.FilePath != mixedCase.FilePath {
+		t.Errorf("Unexpected FilePath: expected %s, found %s", mixedCase.FilePath, another.FilePath)
+	}
+	if another := dir.FileFor(&tengo.Statement{File: filepath.Join(dirPath, "foo.sql")}); another.FilePath != mixedCase.FilePath {
+		t.Errorf("Unexpected FilePath: expected %s, found %s", mixedCase.FilePath, another.FilePath)
+	}
+
+	if runtime.GOOS == "darwin" || runtime.GOOS == "windows" {
+		// Do a variant of above test in which some files already exist. Confirm that
+		// attempts to introduce a conflict just re-use the existing file with
+		// whatever casing it already had.
+		WriteTestFile(t, filepath.Join(dirPath, "AAA.sql"), "CREATE TABLE AAA (id int);\nCREATE TABLE aaa (id int);")
+		WriteTestFile(t, filepath.Join(dirPath, "foobar.sql"), "CREATE TABLE foobar (id int);")
+		dir = getDir(t, dirPath) // need to re-parse dir now that files present
+		if dir.retainMapKeyCasing {
+			t.Fatal("Expected retainMapKeyCasing to be false, but it was true")
+		}
+		if len(dir.SQLFiles) != 2 {
+			t.Errorf("Expected 2 SQL files, instead found %d", len(dir.SQLFiles))
+		}
+		if len(dir.LogicalSchemas[0].Creates) != 3 {
+			t.Errorf("Expected 3 CREATEs, instead found %d", len(dir.LogicalSchemas[0].Creates))
+		}
+		another := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "aAa"})
+		if expected := filepath.Join(dirPath, "AAA.sql"); another.FilePath != expected {
+			t.Errorf("Unexpected FilePath: expected %s, found %s", expected, another.FilePath)
+		}
+		another = dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "FOObar"})
+		if expected := filepath.Join(dirPath, "foobar.sql"); another.FilePath != expected {
+			t.Errorf("Unexpected FilePath: expected %s, found %s", expected, another.FilePath)
+		}
+		if len(dir.SQLFiles) != 2 {
+			t.Errorf("Expected 2 SQL files, instead found %d", len(dir.SQLFiles))
+		}
+
+	} else {
+		// On case-sensitive filesystems, we can do a more thorough test by actually
+		// creating casing conflicts. Test behavior of a dir that has 3 SQL files, 2
+		// of which only differ by casing
+		WriteTestFile(t, filepath.Join(dirPath, "AAA.sql"), "CREATE TABLE AAA (id int);")
+		WriteTestFile(t, filepath.Join(dirPath, "FooBar.sql"), "CREATE TABLE FooBar (id int);")
+		WriteTestFile(t, filepath.Join(dirPath, "foobar.sql"), "CREATE TABLE foobar (id int);")
+		dir = getDir(t, dirPath) // need to re-parse dir now that files present
+		if !dir.retainMapKeyCasing {
+			t.Fatal("Expected retainMapKeyCasing to be true, but it was false")
+		}
+		if len(dir.SQLFiles) != 3 {
+			t.Errorf("Expected 3 SQL files, instead found %d", len(dir.SQLFiles))
+		}
+		mixedCase := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "FooBar"})
+		lowerCase := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "foobar"})
+		if mixedCase.FilePath == lowerCase.FilePath {
+			t.Errorf("Expected paths to differ, but both are %s", mixedCase.FilePath)
+		}
+		upperAAA := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "AAA"})
+		lowerAAA := dir.FileFor(tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "aaa"})
+		if upperAAA.FilePath == lowerAAA.FilePath {
+			t.Errorf("Expected paths to differ, but both are %s", mixedCase.FilePath)
+		}
+		if exists, err := upperAAA.Exists(); !exists || err != nil {
+			t.Errorf("Unexpected return from Exists: %t, %v", exists, err)
+		}
+		if exists, err := lowerAAA.Exists(); exists || err != nil {
+			t.Errorf("Unexpected return from Exists: %t, %v", exists, err)
+		}
+	}
+}
+
 func TestDirBaseName(t *testing.T) {
 	dir := getDir(t, "../../testdata/golden/init/mydb/product")
 	if bn := dir.BaseName(); bn != "product" {
@@ -414,14 +493,84 @@ func TestDirSubdirs(t *testing.T) {
 		t.Errorf("Unexpectedly low subdir count returned: found %d, expected at least 2", len(subs))
 	}
 
-	dir = getDir(t, ".")
+	dir = getDir(t, "testdata")
 	subs, err = dir.Subdirs()
-	if len(subs) != 1 || err != nil || countParseErrors(subs) != 1 {
-		// parse error is from redundant definition of same table between nodelimiter1.sql and nodelimiter2.sql
+	// Expect at least 5 parse errors: 3 with unterminated quotes/comments, 1 bad
+	// symlink in cfgsymlinks2, 1 forbidden statement in createselect
+	if len(subs) < 19 || err != nil || countParseErrors(subs) < 5 {
 		t.Errorf("Unexpected return from Subdirs(): %d subs, %d parse errors, err=%v", len(subs), countParseErrors(subs), err)
 	}
 }
 
+func TestDirFileFor(t *testing.T) {
+	dir := getDir(t, "testdata/host/db")
+
+	// test FileFor with an object that does not yet exist: it should still return
+	// an SQLFile based on the object's default location, but with zero statements
+	key := tengo.ObjectKey{Type: tengo.ObjectTypeTable, Name: "doesnt_exist"}
+	sf := dir.FileFor(key)
+	if sf == nil {
+		t.Error("Dir.FileFor unexpectedly returned nil SQLFile")
+	} else if len(sf.Statements) > 0 {
+		t.Errorf("Expected new SQLFile to have 0 statements, but instead found %d", len(sf.Statements))
+	}
+
+	// test FileFor with an object that already exists: it should return an SQLFile
+	// with one statement
+	key.Name = "comments"
+	sf = dir.FileFor(key)
+	if sf == nil {
+		t.Fatal("Dir.FileFor unexpectedly returned nil SQLFile")
+	} else if len(sf.Statements) != 1 {
+		t.Fatalf("Expected SQLFile to have 1 statement, but instead found %d", len(sf.Statements))
+	}
+
+	// test FileFor with a statement: its return should be based on the File field
+	// of the statement, returning back a pointer to the exact same SQLFile
+	stmt := sf.Statements[0]
+	if sf2 := dir.FileFor(stmt); sf2 != sf {
+		t.Errorf("Unexpected return from FileFor on a statement: expected %+v, found %+v", sf, sf2)
+	}
+
+	// Artificially manipulate the statement: change its name and empty its file
+	// field. FileFor should fall back to the object's default location.
+	origName := stmt.ObjectName
+	stmt.ObjectName += "2"
+	stmt.Text = strings.Replace(stmt.Text, origName, stmt.ObjectName, 1)
+	stmt.File = ""
+	sf3 := dir.FileFor(stmt)
+	if expectedPath := strings.Replace(sf.FilePath, origName, stmt.ObjectName, 1); expectedPath != sf3.FilePath {
+		t.Errorf("Expected return from FileFor to have path %s, instead found %s", expectedPath, sf3.FilePath)
+	}
+}
+
+func TestDirDirtyFiles(t *testing.T) {
+	dir := getDir(t, "testdata/host/db")
+
+	// Expect no dirty file initially
+	if dirties := dir.DirtyFiles(); len(dirties) > 0 {
+		t.Errorf("Expected no dirty files initially, instead found %d", len(dirties))
+	}
+
+	// Artificially mark two files as dirty and confirm they are returned now
+	for filePath, sf := range dir.SQLFiles {
+		if strings.HasSuffix(filePath, "comments.sql") || strings.HasSuffix(filePath, "posts.sql") {
+			sf.Dirty = true
+		}
+	}
+	if dirties := dir.DirtyFiles(); len(dirties) != 2 {
+		t.Errorf("Expected 2 dirty files, instead found %d", len(dirties))
+	} else if dirties[0].FilePath == dirties[1].FilePath {
+		t.Error("Same file returned twice by dir.DirtyFiles()")
+	} else {
+		for _, sf := range dirties {
+			if !strings.HasSuffix(sf.FilePath, "comments.sql") && !strings.HasSuffix(sf.FilePath, "posts.sql") {
+				t.Errorf("Unexpected file returned from dir.DirtyFiles(): %s", sf.FilePath)
+			}
+		}
+	}
+}
+
 func TestDirInstances(t *testing.T) {
 	assertInstances := func(optionValues map[string]string, expectError bool, expectedInstances ...string) []*tengo.Instance {
 		cmd := mybase.NewCommand("test", "1.0", "this is for testing", nil)
