@@ -93,6 +93,22 @@ func TestTableRowFormatClause(t *testing.T) {
 	}
 }
 
+func TestTableUniqueConstraintsWithColumn(t *testing.T) {
+	table := aTable(1)
+	ucs := table.UniqueConstraintsWithColumn(table.Columns[0])
+	if len(ucs) != 1 || ucs[0].Name != "PRIMARY" {
+		t.Errorf("Unexpected return from UniqueConstraintsWithColumn: %v", ucs)
+	}
+	ucs = table.UniqueConstraintsWithColumn(table.Columns[1])
+	if len(ucs) != 0 {
+		t.Errorf("Unexpected return from UniqueConstraintsWithColumn: %v", ucs)
+	}
+	ucs = table.UniqueConstraintsWithColumn(table.Columns[4])
+	if len(ucs) != 1 || ucs[0].Name != "idx_ssn" {
+		t.Errorf("Unexpected return from UniqueConstraintsWithColumn: %v", ucs)
+	}
+}
+
 func TestTableAlterAddOrDropColumn(t *testing.T) {
 	from := aTable(1)
 	to := aTable(1)
@@ -242,6 +258,9 @@ func TestTableAlterAddOrDropIndex(t *testing.T) {
 	if ta2.Index != from.SecondaryIndexes[1] {
 		t.Error("Pointer in table alter[0] does not point to expected value")
 	}
+	if ta2.Clause(StatementModifiers{}) == "" {
+		t.Error("Clause unexpectedly returns blank string")
+	}
 	ta, ok = tableAlters[1].(AddIndex)
 	if !ok {
 		t.Fatalf("Incorrect type of table alter[1] returned: expected %T, found %T", ta, tableAlters[1])
@@ -249,6 +268,49 @@ func TestTableAlterAddOrDropIndex(t *testing.T) {
 	if ta.Index != to.SecondaryIndexes[1] {
 		t.Error("Pointer in table alter[1] does not point to expected value")
 	}
+	if ta.Clause(StatementModifiers{}) == "" {
+		t.Error("Clause unexpectedly returns blank string")
+	}
+
+	// Start over; change the comment of the last existing secondary index, with or
+	// without other changes, and test behavior of StatementModifiers.LaxComments
+	to = aTable(1)
+	to.SecondaryIndexes[1].Comment = "hello I am an index"
+	to.CreateStatement = to.GeneratedCreateStatement(FlavorUnknown)
+	tableAlters, supported = from.Diff(&to)
+	if len(tableAlters) != 2 || !supported {
+		t.Fatalf("Incorrect number of table alters: expected 2, found %d", len(tableAlters))
+	}
+	mods := StatementModifiers{}
+	if tableAlters[0].Clause(mods) == "" || tableAlters[1].Clause(mods) == "" {
+		t.Error("Clause unexpectedly returns blank string")
+	}
+	mods.LaxComments = true
+	if tableAlters[0].Clause(mods) != "" || tableAlters[1].Clause(mods) != "" {
+		t.Error("Clause unexpectedly returns non-blank string")
+	}
+	to.SecondaryIndexes[1].Invisible = true
+	to.CreateStatement = to.GeneratedCreateStatement(FlavorMySQL80)
+	mods.Flavor = FlavorMySQL80
+	tableAlters, supported = from.Diff(&to)
+	if len(tableAlters) != 2 || !supported {
+		t.Fatalf("Incorrect number of table alters: expected 2, found %d", len(tableAlters))
+	}
+	if tableAlters[0].Clause(mods) != "" {
+		t.Error("Clause unexpectedly returns non-blank string")
+	}
+	if clause := tableAlters[1].Clause(mods); !strings.HasPrefix(clause, "ALTER") {
+		t.Errorf("Clause returned unexpected string: %s", clause)
+	}
+	to.SecondaryIndexes[1].Unique = true
+	to.CreateStatement = to.GeneratedCreateStatement(FlavorMySQL80)
+	tableAlters, supported = from.Diff(&to)
+	if len(tableAlters) != 2 || !supported {
+		t.Fatalf("Incorrect number of table alters: expected 2, found %d", len(tableAlters))
+	}
+	if tableAlters[0].Clause(mods) == "" || tableAlters[1].Clause(mods) == "" {
+		t.Error("Clause unexpectedly returns blank string")
+	}
 
 	// Start over; change the primary key
 	to = aTable(1)
@@ -661,7 +723,7 @@ func TestTableAlterModifyColumn(t *testing.T) {
 	to := aTable(1)
 
 	// Reposition a col to first position
-	movedColPos := 3
+	movedColPos := 4
 	movedCol := to.Columns[movedColPos]
 	to.Columns = append(to.Columns[:movedColPos], to.Columns[movedColPos+1:]...)
 	to.Columns = append([]*Column{movedCol}, to.Columns...)
@@ -680,6 +742,9 @@ func TestTableAlterModifyColumn(t *testing.T) {
 	if !ta.PositionFirst || ta.PositionAfter != nil || !strings.Contains(ta.Clause(StatementModifiers{}), " FIRST") {
 		t.Errorf("Expected modified column to be after nil / first=true, instead found after %v / first=%t", ta.PositionAfter, ta.PositionFirst)
 	}
+	if clauseWithMods := ta.Clause(StatementModifiers{LaxColumnOrder: true}); clauseWithMods != "" {
+		t.Errorf("Expected Clause to return a blank string with LaxColumnOrder enabled, instead found: %s", clauseWithMods)
+	}
 
 	// Reposition same col to last position
 	to = aTable(1)
@@ -702,9 +767,14 @@ func TestTableAlterModifyColumn(t *testing.T) {
 	if !ta.NewColumn.Equals(ta.OldColumn) {
 		t.Errorf("Column definition unexpectedly changed: was %s, now %s", ta.OldColumn.Definition(FlavorUnknown, nil), ta.NewColumn.Definition(FlavorUnknown, nil))
 	}
+	if clauseWithMods := ta.Clause(StatementModifiers{LaxColumnOrder: true}); clauseWithMods != "" {
+		t.Errorf("Expected Clause to return a blank string with LaxColumnOrder enabled, instead found: %s", clauseWithMods)
+	}
 
-	// Repos to last position AND change column definition
-	movedCol.Nullable = !movedCol.Nullable
+	// Re-pos to last position AND change column definition, adjusting the
+	// collation. Since this column is used in a unique index, the collation
+	// change should be detected as unsafe.
+	movedCol.Collation = strings.Replace(movedCol.Collation, "general_ci", "unicode_ci", 1)
 	to.CreateStatement = to.GeneratedCreateStatement(FlavorUnknown)
 	tableAlters, supported = from.Diff(&to)
 	if len(tableAlters) != 1 || !supported {
@@ -720,6 +790,15 @@ func TestTableAlterModifyColumn(t *testing.T) {
 	if ta.NewColumn.Equals(ta.OldColumn) {
 		t.Errorf("Column definition unexpectedly NOT changed: still %s", ta.NewColumn.Definition(FlavorUnknown, nil))
 	}
+	if !ta.InUniqueConstraint {
+		t.Error("Expected InUniqueConstraint to be true, but it was false")
+	}
+	if ta.Clause(StatementModifiers{LaxColumnOrder: true}) == "" {
+		t.Error("Since non-positioning changes are present, expected Clause to return a non-blank string even with LaxColumnOrder enabled, but it was blank")
+	}
+	if unsafe, reason := ta.Unsafe(); !unsafe || !strings.Contains(reason, movedCol.Name) {
+		t.Errorf("Unexpected return from Unsafe(): %t, %q", unsafe, reason)
+	}
 
 	// Start over; delete a col, move last col to its former position, and add a new col after that
 	// FROM: actor_id, first_name, last_name, last_updated, ssn, alive, alive_bit
@@ -1169,6 +1248,7 @@ func TestTableAlterChangeComment(t *testing.T) {
 		return t
 	}
 	assertChangeComment := func(a, b *Table, expected string) {
+		t.Helper()
 		tableAlters, supported := a.Diff(b)
 		if expected == "" {
 			if len(tableAlters) != 0 || !supported {
@@ -1194,6 +1274,24 @@ func TestTableAlterChangeComment(t *testing.T) {
 	to = getTableWithComment("I'm a table-level comment!")
 	assertChangeComment(&from, &to, "COMMENT 'I''m a table-level comment!'")
 	assertChangeComment(&to, &from, "COMMENT ''")
+
+	// Test behavior of StatementModifiers.LaxComments: should suppress the comment
+	// change only if there are no other alterations to the table. This behavior
+	// is implemented at the TableDiff level, rather than AlterClause.
+	assertChangeCommentLax := func(a, b *Table, expectDiff bool) {
+		t.Helper()
+		stmt, err := NewAlterTable(a, b).Statement(StatementModifiers{LaxComments: true, AllowUnsafe: true})
+		if err != nil {
+			t.Errorf("Unexpected error returned from Statment: %v", err)
+		} else if (stmt != "") != expectDiff {
+			t.Errorf("Unexpected return string from Statement: %q", stmt)
+		}
+	}
+	assertChangeCommentLax(&from, &to, false)
+	assertChangeCommentLax(&to, &from, false)
+	to.Columns[0].TypeInDB = "smallint(5)"
+	assertChangeCommentLax(&from, &to, true)
+	assertChangeCommentLax(&to, &from, true)
 }
 
 func TestTableAlterTablespace(t *testing.T) {
@@ -1280,7 +1378,7 @@ func BenchmarkColumnModifications(b *testing.B) {
 	}
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
-		cc := tbl1.compareColumnExistence(tbl2)
+		cc := compareColumnExistence(tbl1, tbl2)
 		cc.columnModifications()
 	}
 }
