@@ -14,23 +14,13 @@ func TestMain(m *testing.M) {
 }
 
 func TestIntegration(t *testing.T) {
-	images := SplitEnv("SKEEMA_TEST_IMAGES")
-	if len(images) == 0 {
-		fmt.Println("SKEEMA_TEST_IMAGES env var is not set, so integration tests will be skipped!")
-		fmt.Println("To run integration tests, you may set SKEEMA_TEST_IMAGES to a comma-separated")
-		fmt.Println("list of Docker images. Example:\n# SKEEMA_TEST_IMAGES=\"mysql:5.6,mysql:5.7\" go test")
-	}
-	manager, err := NewDockerClient(DockerClientOptions{})
-	if err != nil {
-		t.Errorf("Unable to create sandbox manager: %s", err)
-	}
-	suite := &TengoIntegrationSuite{manager: manager}
+	images := SkeemaTestImages(t)
+	suite := &TengoIntegrationSuite{}
 	RunSuite(suite, t, images)
 }
 
 type TengoIntegrationSuite struct {
-	manager *DockerClient
-	d       *DockerizedInstance
+	d *DockerizedInstance
 }
 
 func (s *TengoIntegrationSuite) Setup(backend string) (err error) {
@@ -40,7 +30,7 @@ func (s *TengoIntegrationSuite) Setup(backend string) (err error) {
 		RootPassword: "fakepw",
 		CommandArgs:  []string{"--skip-log-bin"}, // override MySQL 8 default of enabling binlog
 	}
-	s.d, err = s.manager.GetOrCreateInstance(opts)
+	s.d, err = GetOrCreateDockerizedInstance(opts)
 	return err
 }
 
@@ -60,11 +50,11 @@ func (s *TengoIntegrationSuite) BeforeTest(backend string) error {
 // relative to the testdata subdir. If any errors occur, the test fails.
 func (s *TengoIntegrationSuite) SourceTestSQL(t *testing.T, files ...string) {
 	t.Helper()
-	for _, f := range files {
-		fPath := filepath.Join("testdata", f)
-		if _, err := s.d.SourceSQL(fPath); err != nil {
-			t.Fatal(err.Error())
-		}
+	for n := range files {
+		files[n] = filepath.Join("testdata", files[n])
+	}
+	if _, err := s.d.SourceSQL(files...); err != nil {
+		t.Fatal(err.Error())
 	}
 }
 
@@ -158,7 +148,7 @@ func TestUnitTableFlavors(t *testing.T) {
 // subtest.
 func flavorTestFiles(flavor Flavor) []string {
 	// Non-flavor-specific
-	result := []string{"integration-ext.sql", "partition.sql", "rows.sql", "views.sql"}
+	result := []string{"integration-ext.sql", "partition.sql", "rows.sql", "views.sql", "spatial.sql"}
 
 	if flavor.Min(FlavorMySQL80.Dot(13)) {
 		result = append(result, "default-expr.sql")
@@ -640,43 +630,3 @@ func aSchema(name string, tables ...*Table) Schema {
 	}
 	return s
 }
-
-func aProc(dbCollation, sqlMode string) Routine {
-	r := Routine{
-		Name: "proc1",
-		Type: ObjectTypeProc,
-		Body: `BEGIN
-  SELECT @iterations + 1, 98.76 INTO iterations, pct;
-  END`,
-		ParamString:       "\n    IN name varchar(30) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin,\n    INOUT iterations int(10) unsigned,   OUT pct decimal(5, 2)\n",
-		ReturnDataType:    "",
-		Definer:           "root@%",
-		DatabaseCollation: dbCollation,
-		Comment:           "",
-		Deterministic:     false,
-		SQLDataAccess:     "READS SQL DATA",
-		SecurityType:      "INVOKER",
-		SQLMode:           sqlMode,
-	}
-	r.CreateStatement = r.Definition(FlavorUnknown)
-	return r
-}
-
-func aFunc(dbCollation, sqlMode string) Routine {
-	r := Routine{
-		Name:              "func1",
-		Type:              ObjectTypeFunc,
-		Body:              "return mult * 2.0",
-		ParamString:       "mult float(10,2)",
-		ReturnDataType:    "float",
-		Definer:           "root@%",
-		DatabaseCollation: dbCollation,
-		Comment:           "hello world",
-		Deterministic:     true,
-		SQLDataAccess:     "NO SQL",
-		SecurityType:      "DEFINER",
-		SQLMode:           sqlMode,
-	}
-	r.CreateStatement = r.Definition(FlavorUnknown)
-	return r
-}
