@@ -25,23 +25,13 @@ func TestMain(m *testing.M) {
 }
 
 func TestIntegration(t *testing.T) {
-	images := tengo.SplitEnv("SKEEMA_TEST_IMAGES")
-	if len(images) == 0 {
-		fmt.Println("SKEEMA_TEST_IMAGES env var is not set, so integration tests will be skipped!")
-		fmt.Println("To run integration tests, you may set SKEEMA_TEST_IMAGES to a comma-separated")
-		fmt.Println("list of Docker images. Example:\n# SKEEMA_TEST_IMAGES=\"mysql:5.6,mysql:5.7\" go test")
-	}
-	manager, err := tengo.NewDockerClient(tengo.DockerClientOptions{})
-	if err != nil {
-		t.Errorf("Unable to create sandbox manager: %s", err)
-	}
-	suite := &WorkspaceIntegrationSuite{manager: manager}
+	images := tengo.SkeemaTestImages(t)
+	suite := &WorkspaceIntegrationSuite{}
 	tengo.RunSuite(suite, t, images)
 }
 
 type WorkspaceIntegrationSuite struct {
-	manager *tengo.DockerClient
-	d       *tengo.DockerizedInstance
+	d *tengo.DockerizedInstance
 }
 
 func (s WorkspaceIntegrationSuite) TestExecLogicalSchema(t *testing.T) {
@@ -314,7 +304,7 @@ func (s WorkspaceIntegrationSuite) TestPrefab(t *testing.T) {
 }
 
 func (s *WorkspaceIntegrationSuite) Setup(backend string) (err error) {
-	s.d, err = s.manager.GetOrCreateInstance(tengo.DockerizedInstanceOptions{
+	s.d, err = tengo.GetOrCreateDockerizedInstance(tengo.DockerizedInstanceOptions{
 		Name:         fmt.Sprintf("skeema-test-%s", tengo.ContainerNameForImage(backend)),
 		Image:        backend,
 		RootPassword: "fakepw",
