@@ -295,6 +295,7 @@ func (s SkeemaIntegrationSuite) TestLintHandler(t *testing.T) {
 	// Invalid options should error with CodeBadConfig
 	s.handleCommand(t, CodeBadConfig, ".", "skeema lint --workspace=doesnt-exist")
 	s.handleCommand(t, CodeBadConfig, "mydb/product", "skeema lint --password=wrong")
+	s.handleCommand(t, CodeBadConfig, ".", "skeema lint --lint-pk=fatal")
 
 	// Alter a few files in a way that is still valid SQL, but doesn't match
 	// the database's native format. Lint with --skip-format should do nothing;
@@ -444,9 +445,28 @@ func (s SkeemaIntegrationSuite) TestDiffHandler(t *testing.T) {
 		t.Error("Expected --skip-dry-run to have no effect on `skeema diff`, but it disabled dry-run")
 	}
 
+	// Confirm simple diff that adds a column
 	s.dbExec(t, "analytics", "ALTER TABLE pageviews DROP COLUMN domain")
 	s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff")
 
+	// Confirm behavior of lax-column-order
+	s.dbExec(t, "product", "ALTER TABLE posts MODIFY COLUMN `body` text FIRST")
+	s.handleCommand(t, CodeDifferencesFound, "mydb/product", "skeema diff")
+	s.handleCommand(t, CodeSuccess, "mydb/product", "skeema diff --lax-column-order")
+
+	// Undo the previous change, and then confirm behavior of lax-comments
+	s.handleCommand(t, CodeSuccess, "mydb/product", "skeema push")
+	s.handleCommand(t, CodeSuccess, "mydb/product", "skeema diff") // just confirming push had the intended effect
+	s.dbExec(t, "product", "ALTER TABLE posts COMMENT 'hello world table comment', MODIFY COLUMN `body` text COMMENT 'hello world column comment'")
+	s.handleCommand(t, CodeDifferencesFound, "mydb/product", "skeema diff")
+	s.handleCommand(t, CodeSuccess, "mydb/product", "skeema diff --lax-comments")
+
+	// Test combination of lax-comments with lax-column-order
+	s.dbExec(t, "product", "ALTER TABLE posts COMMENT 'hello world table comment', MODIFY COLUMN `body` text COMMENT 'hello world column comment' FIRST")
+	s.handleCommand(t, CodeDifferencesFound, "mydb/product", "skeema diff --lax-comments")
+	s.handleCommand(t, CodeDifferencesFound, "mydb/product", "skeema diff --lax-column-order")
+	s.handleCommand(t, CodeSuccess, "mydb/product", "skeema diff --lax-comments --lax-column-order")
+
 	// Confirm --brief works as expected
 	defer func() {
 		// --brief manipulates the log level, so we must restore it after
@@ -983,9 +1003,9 @@ func (s SkeemaIntegrationSuite) TestNonInnoClauses(t *testing.T) {
 	// MariaDB does not consider STORAGE or COLUMN_FORMAT clauses as valid SQL.
 	// Ditto for MySQL 5.5.
 	if s.d.Flavor().IsMariaDB() {
-		t.Skip("Test not relevant for MariaDB-based image", s.d.Image)
+		t.Skip("Test not relevant for MariaDB-based image", s.d.Flavor())
 	} else if s.d.Flavor().Matches(tengo.FlavorMySQL55) {
-		t.Skip("Test not relevant for 5.5-based image", s.d.Image)
+		t.Skip("Test not relevant for 5.5-based image", s.d.Flavor())
 	}
 
 	withClauses := "CREATE TABLE `problems` (\n" +
@@ -1401,6 +1421,37 @@ END`
 			t.Errorf("Expected %s to exist, instead found %t, err=%v", phrase, exists, err)
 		}
 	}
+
+	// Change procedure routine2's characteristics in the db. Do a push, which
+	// should use ALTER PROCEDURE and be safe.
+	s.dbExec(t, "product", "ALTER PROCEDURE routine2 SQL SECURITY INVOKER READS SQL DATA")
+	s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff")
+	s.handleCommand(t, CodeSuccess, ".", "skeema push")
+	s.handleCommand(t, CodeSuccess, ".", "skeema diff")
+
+	// Repeat the previous test, but this time add a COMMENT. Due to a server bug
+	// in MySQL 8.0+, ALTER ... COMMENT '' does not function properly, so Skeema
+	// always emits DROP/re-CREATE (or CREATE OR REPLACE) in this situation for
+	// MySQL 8.0+.
+	// Also confirm that --lax-comments does not suppress these diffs, since other
+	// characteristics besides the comment are also being changed.
+	s.dbExec(t, "product", "ALTER PROCEDURE routine2 SQL SECURITY INVOKER READS SQL DATA COMMENT 'whatever'")
+	if s.d.Flavor().Min(tengo.FlavorMySQL80) {
+		s.handleCommand(t, CodeFatalError, ".", "skeema diff --lax-comments")
+		s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff --allow-unsafe --lax-comments")
+		s.handleCommand(t, CodeSuccess, ".", "skeema push --allow-unsafe --lax-comments")
+	} else {
+		s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff --lax-comments")
+		s.handleCommand(t, CodeSuccess, ".", "skeema push --lax-comments")
+	}
+	s.handleCommand(t, CodeSuccess, ".", "skeema diff")
+
+	// Repeat the previous test, this time ONLY adding a comment, and confirm that
+	// use of --lax-comments suppresses the diff entirely.
+	s.dbExec(t, "product", "ALTER PROCEDURE routine2 COMMENT 'whatever'")
+	s.handleCommand(t, CodeSuccess, ".", "skeema diff --lax-comments")
+	s.handleCommand(t, CodeSuccess, ".", "skeema push --lax-comments")
+	s.handleCommand(t, CodeDifferencesFound, ".", "skeema diff --allow-unsafe")
 }
 
 // TestTempSchemaBinlog provides coverage for the temp-schema-binlog option.
@@ -1415,10 +1466,13 @@ func (s SkeemaIntegrationSuite) TestTempSchemaBinlog(t *testing.T) {
 	}
 
 	// Create an instance with log-bin enabled
-	opts := s.d.DockerizedInstanceOptions
-	opts.Name = strings.Replace(opts.Name, "skeema-test-", "skeema-test-binlog-", 1)
-	opts.CommandArgs = []string{"--log-bin", "--server-id=1"}
-	dinst, err := s.manager.GetOrCreateInstance(opts)
+	opts := tengo.DockerizedInstanceOptions{
+		Name:         strings.Replace(s.d.ContainerName(), "skeema-test-", "skeema-test-binlog-", 1),
+		Image:        s.d.Flavor().Family().String(),
+		RootPassword: s.d.Password,
+		CommandArgs:  []string{"--log-bin", "--server-id=1"},
+	}
+	dinst, err := tengo.GetOrCreateDockerizedInstance(opts)
 	if err != nil {
 		t.Fatalf("Unable to create Dockerized instance with log-bin enabled: %v", err)
 	}
